<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category settings
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Sep 3, 2013 2:37:36 PM
 * @version $Rev$
 */

/**
 * TellAFriend class
 * Used to ....
 */
class Entity_Form_TellAFriend {

    private $interfacer = null;
    private $publication_id = 0;

    public function __construct($publication_id) {
        $this->interfacer = WP_Interfacer::getInstance();
        $this->publication_id = $publication_id;
    }

    public function display() {
        $backtrace = debug_backtrace();
        foreach ($backtrace as $bkt) {
            if (isset($bkt['file'])) {
                if (basename($bkt['file']) == 'class-frontend.php')
                    return '';
            }
        }
        $data = array();
        $errors = array();
        $input_data = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);
        $general_error = '';
        $captchaStatus = Environment_Settings::getTAFCaptchaStatus();
        
        if ($input_data !== NULL && wp_verify_nonce($input_data['_carerix_nonce_field'], 'tellafriend')) {
            $labels = Utils_Labels::get();
            if (strlen(trim($input_data['from_email'])) == 0) {
                $errors['from_email'] = $labels['CxPortal.message.mandatory.mandatory'];
            } elseif (!filter_var($input_data['from_email'], FILTER_VALIDATE_EMAIL)) {
                $errors['from_email'] = $labels['general.message.format.invalidEnteredEmail'];
            }
            if (strlen(trim($input_data['to_email'])) == 0) {
                $errors['to_email'] = $labels['CxPortal.message.mandatory.mandatory'];
            } elseif (!filter_var($input_data['to_email'], FILTER_VALIDATE_EMAIL)) {
                $errors['to_email'] = $labels['general.message.format.invalidEnteredEmail'];
            }

            if ($captchaStatus == 'on' && strtolower($input_data['captcha_code']) !== strtolower($_SESSION['captcha']['code'])) {
                $errors['captcha'] = $labels['CxWpPlugin.message.captcha'];
            }

            if (count($errors) == 0) {
                $from_email = $input_data['from_email'];
                $from_name = $input_data['from_name'];

                $to_email = $input_data['to_email'];
                $to_name = $input_data['to_name'];

                $headers = array();
                $headers[] = "From: $from_name <$from_email>";
                $headers[] = "To: $to_name <$to_email>";

                $labels = Utils_Labels::get();
                $subject = $labels['CxPortal.message.field.emailSubject'];

                $message = $labels['CxPortal.message.field.emailContent'];
                global $post;
                $joblink = '<a href="' . $this->interfacer->get_post_permalink() . '">' . $post->post_title . '</a>';
                $message = str_replace('{jobLink}', $joblink, $message);

                $parameters = array(
                    'from' => $input_data['from_email'],
                    'to' => $input_data['to_email'],
                    'emailtemplate' => 'cxpTellFriend',
                    'ID' => (int) $this->publication_id,
                );

                $general_exception = false;

                try {
                    $publication = new Carerix_Api_Rest_Entity_CRPublication();
                    $publication->setId((int) $this->publication_id);
                    $publication->email($parameters);
                    $data['succesful'] = true;
                } catch (Carerix_Api_Rest_Exception $care) {
                    $general_error = $care->getMessage();
                    $general_exception = $care;
                } catch (Exception $ex) {
                    $general_error = $ex->getMessage();
                    $general_exception = $ex;
                }
                if ($general_exception) {
                    //Utils_Log::write(Utils_Log::TYPE_TAF, $publication, $general_exception);
                    $this->interfacer->email($to_email, $subject, $message, $headers);
                }

                $data['succesful'] = true;
            }
        }

        $data['errors'] = $errors;
        $data['general_error'] = $general_error;
        $data['captcha'] = $captchaStatus;

        $template = new Utils_Template('frontend/forms/tellafriend');
        $template->with($data)->display();
    }

}
